@@ -15,7 +15,7 @@ import sys
 from datetime import datetime
 from typing import IO, Any, Dict, List, Union
 
-from .literals import StatusString
+from .literals import StatusStringType
 
 if sys.version_info >= (3, 8):
     from typing import TypedDict
@@ -91,7 +91,7 @@ _OptionalDescribeStatementResponseTypeDef = TypedDict(
         "ResultRows": int,
         "ResultSize": int,
         "SecretArn": str,
-        "Status": StatusString,
+        "Status": StatusStringType,
         "UpdatedAt": datetime,
     },
     total=False,
@@ -245,7 +245,7 @@ _OptionalStatementDataTypeDef = TypedDict(
         "QueryString": str,
         "SecretArn": str,
         "StatementName": str,
-        "Status": StatusString,
+        "Status": StatusStringType,
         "UpdatedAt": datetime,
     },
     total=False,
